@@ -8,6 +8,7 @@ extensions = [
     'sphinx.ext.intersphinx',
     'jaraco.packaging.sphinx',
     'rst.linker',
+    'sphinx_tabs.tabs',
 ]
 
 master_doc = 'index'
@@ -41,5 +42,7 @@ extlinks = {
 
 intersphinx_mapping = {
     'python': ('https://docs.python.org/3', None),
-    'cherrypy': ('http://docs.cherrypy.org/en/latest/', None),
+    'python2': ('https://docs.python.org/2', None),
+    'cherrypy': ('https://docs.cherrypy.org/en/latest/', None),
+    'trustme': ('https://trustme.readthedocs.io/en/latest/', None),
 }
